<?php
namespace Zotlabs\Module;

use App;
use Zotlabs\Lib\Apps;
use Zotlabs\Web\Controller;

/**
 * module: invitexv2.php
 *
 * send email invitations to join social network
 *
 */


class Invite extends Controller {

	function post() {
	
		if(! local_channel()) {
			notice( t('Permission denied.') . EOL);
			return;
		}

		if(! Apps::system_app_installed(local_channel(), 'Invite')) {
			return;
		}
	
		check_form_security_token_redirectOnErr('/', 'send_invite');
	
		$max_invites = intval(get_config('system','max_invites'));
		if(! $max_invites)
			$max_invites = 50;
	
		$current_invites = intval(get_pconfig(local_channel(),'system','sent_invites'));
		if($current_invites > $max_invites) {
			notice( t('Total invitation limit exceeded.') . EOL);
			return;
		};
	
	
		$recips  = ((x($_POST,'recipients')) ? explode("\n",$_POST['recipients']) : array());
		$message = ((x($_POST,'message'))    ? notags(trim($_POST['message']))    : '');
	
		$total = 0;
	
		if(get_config('system','invitation_only')) {
			$invonly = true;
			$x = get_pconfig(local_channel(),'system','invites_remaining');
			if((! $x) && (! is_site_admin()))
				return;
		}
	
		foreach($recips as $recip) {
	
			$recip = trim($recip);
			if(! $recip)
				continue;
	
			if(! validate_email($recip)) {
				notice(  sprintf( t('%s : Not a valid email address.'), $recip) . EOL);
				continue;
			}
	
			else
				$nmessage = $message;
	
			$account = App::get_account();
	
			$res = z_mail(
				[ 
				'toEmail'        => $recip,
				'fromName'       => ' ',
				'fromEmail'      => $account['account_email'],
				'messageSubject' => t('Please join us on $Projectname'),
				'textVersion'    => $nmessage,
				]
			);
	
			if($res) {
				$total ++;
				$current_invites ++;
				set_pconfig(local_channel(),'system','sent_invites',$current_invites);
				if($current_invites > $max_invites) {
					notice( t('Invitation limit exceeded. Please contact your site administrator.') . EOL);
					return;
				}
			}
			else {
				notice( sprintf( t('%s : Message delivery failed.'), $recip) . EOL);
			}
	
		}
		notice( sprintf( tt("%d message sent.", "%d messages sent.", $total) , $total) . EOL);
		return;
	}
	
	
	function get() {
	
		if(! local_channel()) {
			notice( t('Permission denied.') . EOL);
			return;
		}

		if(! Apps::system_app_installed(local_channel(), 'Invite')) {
			//Do not display any associated widgets at this point
			App::$pdl = '';

			$o = '<b>' . t('Invite App') . ' (' . t('Not Installed') . '):</b><br>';
			$o .= t('Send email invitations to join this network');
			return $o;
		}

		nav_set_selected('Invite');
	
		$tpl = get_markup_template('invitexv2.tpl');
		$invonly = false;
	
		if(get_config('system','invitation_only')) {
			$invonly = true;
			$x = get_pconfig(local_channel(),'system','invites_remaining');
			if((! $x) && (! is_site_admin())) {
				notice( t('You have no more invitations available') . EOL);
				return '';
			}
		}
	
			if($invonly && ($x || is_site_admin())) {
				$invite_code = autoname(8) . rand(1000,9999);
				$nmessage = str_replace('$invite_code',$invite_code,$message);
	
				$r = q("INSERT INTO register (hash,created,uid,password,lang) VALUES ('%s', '%s',0,'','') ",
					dbesc($invite_code),
					dbesc(datetime_convert())
				);
	
				if(! is_site_admin()) {
					$x --;
					if($x >= 0)
						set_pconfig(local_channel(),'system','invites_remaining',$x);
					else
						return;
				}
			}
	
		$ob = App::get_observer();
		if(! $ob)
			return $o;
	
		$channel = App::get_channel();

		// @hilmar (
		$aidme	= 'acm'; // my ap & msg id prefix
		$mylc	= ((isset(App::$config['system']['language'])) ? App::$config['system']['language'] : 'en');
		$tpls	= glob('view/en/invite.*.tpl');
		$langs 	= str_replace( array('view/', '/invite.casual.tpl'), '', glob('view/*/invite.casual.tpl'));
		asort($langs);
		$tao='tao.acm.mycc = ' . "'" . $mylc . "';\n" . 'tao.acm.invite = ' . "'" . 'casual' . "';\n";
		$lco=$tx=$stx=$tplin='';
		$syml='<span class="fa acmfa"></span>';
		$symt='<span class="fa acmfa"></span>';
		foreach ($langs as $lang) {
			$hi = ($lang == $mylc) ? ' acmhi' : '';
			$lcc = str_replace('-', '_', $lang);
			$tao .= 'tao.acm.' . $lcc . ' = {};' . "\n";
			$lco .= $syml . '<a href="javascript:;" class="acmcc'
					. $hi . '">'. $lcc . '</a>';
			$tpls = glob('view/'.$lang.'/invite.*.tpl');
			foreach ($tpls as $tpli) {
				$tp = str_replace( array('view/'.$lang.'/invite.', '.tpl'), '', $tpli);
				$hi = ($tp == 'casual') ? ' acmhi' : '';
				($lang == 'en')
				?	$tplin .= $symt.'<a href="javascript:;" id="acm-' . $tp
					. '" class="invites'.$hi.'">' . $tp . '</a>' : '';
				push_lang($lang);
				$tx = replace_macros(get_intltext_template('invite.'.$tp.'.tpl'), 
					array(
					'$projectname'		=> t('$Projectname'),
					'$invite_code'		=> $invite_code,
					'$invite_where' 	=> z_root() . '/register',
					'$invite_whereami'	=> $ob['xchan_addr'],
					'$invite_whoami'	=> z_root() . '/channel/' . $channel['channel_address'],
					'$invite_anywhere'	=> z_root() . '/pubsites'
					)
				);
				pop_lang();
				$tao .= 'tao.acm.' . $lcc . '.' . $tp . " = '" . rawurlencode($tx) . "';\n"; 
				($lang == $mylc && $tp == 'casual') ? $stx=$tx : '';
			}
		}
		$o = replace_macros($tpl, array(
			'$form_security_token' => get_form_security_token("send_invite"),
			'$invite' => t('Send invitations'),
			'$addr_text' => t('Enter email addresses, one per line:'),
			'$msg_text' => t('Your message:'),
			'$lco'		=> $lco,
			'$tplin'	=> $tplin,
			'$tao'		=> $tao,
			'$standard_message_label' => 'Standard invitation',
			'$standard_message' => $stx,
			'$personal_message' => '',
			'$personal_pointer' => t('Here you may enter personal notes to the recipient(s)'),
			'$submit' => t('Submit')
		));
		// @hilmar )

		/*
		$o = replace_macros($tpl, array(
			'$form_security_token' => get_form_security_token("send_invite"),
			'$invite' => t('Send invitations'),
			'$addr_text' => t('Enter email addresses, one per line:'),
			'$msg_text' => t('Your message:'),

			'$standard_message_label' => 'Standard invitation',
			'$standard_message' => 'Standard Text for invitation',
			'$default_message' => t('Please join my community on $Projectname.') . "\r\n" . "\r\n"
				. $linktxt
				. (($invonly) ? "\r\n" . "\r\n" . t('You will need to supply this invitation code:') . " " . $invite_code . "\r\n" . "\r\n" : '')
				. t('1. Register at any $Projectname location (they are all inter-connected)')
				. "\r\n" . "\r\n" . z_root() . '/register'
				. "\r\n" . "\r\n" . t('2. Enter my $Projectname network address into the site searchbar.')
				. "\r\n" . "\r\n" . $ob['xchan_addr'] . ' (' . t('or visit') . " " . z_root() . '/channel/' . $channel['channel_address'] . ')'
				. "\r\n" . "\r\n"
				. t('3. Click [Connect]')
				. "\r\n" . "\r\n"  ,
			'$submit' => t('Submit')
		));
		*/
	
		return $o;
	}
	
}
